/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.16.1
 */

#include "sipAPIrcc_backend.h"

#line 25 "/build/calibre/src/calibre-9.13.0/build/pyqt/rcc_backend/rcc.sip"
#include "rcc.h"
#line 12 "/build/calibre/src/calibre-9.13.0/build/pyqt/rcc_backend/build/rcc_backend/siprcc_backendRCCResourceLibrary.cpp"

#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 16 "/build/calibre/src/calibre-9.13.0/build/pyqt/rcc_backend/build/rcc_backend/siprcc_backendRCCResourceLibrary.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 19 "/build/calibre/src/calibre-9.13.0/build/pyqt/rcc_backend/build/rcc_backend/siprcc_backendRCCResourceLibrary.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 22 "/build/calibre/src/calibre-9.13.0/build/pyqt/rcc_backend/build/rcc_backend/siprcc_backendRCCResourceLibrary.cpp"


PyDoc_STRVAR(doc_RCCResourceLibrary_output, "output(self, outDevice: QIODevice, tempDevice: QIODevice, errorDevice: QIODevice) -> bool");

extern "C" {static PyObject *meth_RCCResourceLibrary_output(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_output(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QIODevice* a1;
        ::QIODevice* a2;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9J9", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, sipType_QIODevice, &a0, sipType_QIODevice, &a1, sipType_QIODevice, &a2))
        {
            bool sipRes;

            sipRes = sipCpp->output(*a0, *a1, *a2);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_output, doc_RCCResourceLibrary_output);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_readFiles, "readFiles(self, listMode: bool, errorDevice: QIODevice) -> bool");

extern "C" {static PyObject *meth_RCCResourceLibrary_readFiles(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_readFiles(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QIODevice* a1;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BbJ9", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, &a0, sipType_QIODevice, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->readFiles(a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_readFiles, doc_RCCResourceLibrary_readFiles);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_setInputFiles, "setInputFiles(self, files: Iterable[str|None])");

extern "C" {static PyObject *meth_RCCResourceLibrary_setInputFiles(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_setInputFiles(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStringList* a0;
        int a0State = 0;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setInputFiles(*a0);
            sipReleaseType(a0, sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_setInputFiles, doc_RCCResourceLibrary_setInputFiles);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_setFormat, "setFormat(self, f: RCCResourceLibrary.Format)");

extern "C" {static PyObject *meth_RCCResourceLibrary_setFormat(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_setFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::RCCResourceLibrary::Format a0;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, sipType_RCCResourceLibrary_Format, &a0))
        {
            sipCpp->setFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_setFormat, doc_RCCResourceLibrary_setFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_format, "format(self) -> RCCResourceLibrary.Format");

extern "C" {static PyObject *meth_RCCResourceLibrary_format(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_format(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            ::RCCResourceLibrary::Format sipRes;

            sipRes = sipCpp->format();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_RCCResourceLibrary_Format);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_format, doc_RCCResourceLibrary_format);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_setCompressionAlgorithm, "setCompressionAlgorithm(self, algo: RCCResourceLibrary.CompressionAlgorithm)");

extern "C" {static PyObject *meth_RCCResourceLibrary_setCompressionAlgorithm(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_setCompressionAlgorithm(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::RCCResourceLibrary::CompressionAlgorithm a0;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, sipType_RCCResourceLibrary_CompressionAlgorithm, &a0))
        {
            sipCpp->setCompressionAlgorithm(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_setCompressionAlgorithm, doc_RCCResourceLibrary_setCompressionAlgorithm);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_compressionAlgorithm, "compressionAlgorithm(self) -> RCCResourceLibrary.CompressionAlgorithm");

extern "C" {static PyObject *meth_RCCResourceLibrary_compressionAlgorithm(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_compressionAlgorithm(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            ::RCCResourceLibrary::CompressionAlgorithm sipRes;

            sipRes = sipCpp->compressionAlgorithm();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_RCCResourceLibrary_CompressionAlgorithm);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_compressionAlgorithm, doc_RCCResourceLibrary_compressionAlgorithm);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_dataFiles, "dataFiles(self) -> list[str]");

extern "C" {static PyObject *meth_RCCResourceLibrary_dataFiles(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_dataFiles(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->dataFiles());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_dataFiles, doc_RCCResourceLibrary_dataFiles);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_setVerbose, "setVerbose(self, b: bool)");

extern "C" {static PyObject *meth_RCCResourceLibrary_setVerbose(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_setVerbose(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, &a0))
        {
            sipCpp->setVerbose(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_setVerbose, doc_RCCResourceLibrary_setVerbose);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_verbose, "verbose(self) -> bool");

extern "C" {static PyObject *meth_RCCResourceLibrary_verbose(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_verbose(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->verbose();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_verbose, doc_RCCResourceLibrary_verbose);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_setResourceRoot, "setResourceRoot(self, root: str|None)");

extern "C" {static PyObject *meth_RCCResourceLibrary_setResourceRoot(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_setResourceRoot(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setResourceRoot(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_setResourceRoot, doc_RCCResourceLibrary_setResourceRoot);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_resourceRoot, "resourceRoot(self) -> str");

extern "C" {static PyObject *meth_RCCResourceLibrary_resourceRoot(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_resourceRoot(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->resourceRoot());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_resourceRoot, doc_RCCResourceLibrary_resourceRoot);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_setInitName, "setInitName(self, name: str|None)");

extern "C" {static PyObject *meth_RCCResourceLibrary_setInitName(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_setInitName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setInitName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_setInitName, doc_RCCResourceLibrary_setInitName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_initName, "initName(self) -> str");

extern "C" {static PyObject *meth_RCCResourceLibrary_initName(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_initName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->initName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_initName, doc_RCCResourceLibrary_initName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_setOutputName, "setOutputName(self, name: str|None)");

extern "C" {static PyObject *meth_RCCResourceLibrary_setOutputName(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_setOutputName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setOutputName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_setOutputName, doc_RCCResourceLibrary_setOutputName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_outputName, "outputName(self) -> str");

extern "C" {static PyObject *meth_RCCResourceLibrary_outputName(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_outputName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->outputName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_outputName, doc_RCCResourceLibrary_outputName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_setUseNameSpace, "setUseNameSpace(self, v: bool)");

extern "C" {static PyObject *meth_RCCResourceLibrary_setUseNameSpace(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_setUseNameSpace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, &a0))
        {
            sipCpp->setUseNameSpace(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_setUseNameSpace, doc_RCCResourceLibrary_setUseNameSpace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_useNameSpace, "useNameSpace(self) -> bool");

extern "C" {static PyObject *meth_RCCResourceLibrary_useNameSpace(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_useNameSpace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->useNameSpace();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_useNameSpace, doc_RCCResourceLibrary_useNameSpace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_failedResources, "failedResources(self) -> list[str]");

extern "C" {static PyObject *meth_RCCResourceLibrary_failedResources(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_failedResources(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->failedResources());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_failedResources, doc_RCCResourceLibrary_failedResources);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_formatVersion, "formatVersion(self) -> int");

extern "C" {static PyObject *meth_RCCResourceLibrary_formatVersion(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_formatVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->formatVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_formatVersion, doc_RCCResourceLibrary_formatVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_setNoZstd, "setNoZstd(self, v: bool)");

extern "C" {static PyObject *meth_RCCResourceLibrary_setNoZstd(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_setNoZstd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_RCCResourceLibrary, &sipCpp, &a0))
        {
            sipCpp->setNoZstd(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_setNoZstd, doc_RCCResourceLibrary_setNoZstd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_RCCResourceLibrary_noZstd, "noZstd(self) -> bool");

extern "C" {static PyObject *meth_RCCResourceLibrary_noZstd(PyObject *, PyObject *);}
static PyObject *meth_RCCResourceLibrary_noZstd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::RCCResourceLibrary *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_RCCResourceLibrary, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->noZstd();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_RCCResourceLibrary, sipName_noZstd, doc_RCCResourceLibrary_noZstd);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_RCCResourceLibrary(void *, int);}
static void release_RCCResourceLibrary(void *sipCppV, int)
{
    delete reinterpret_cast< ::RCCResourceLibrary *>(sipCppV);
}


extern "C" {static void *array_RCCResourceLibrary(Py_ssize_t);}
static void *array_RCCResourceLibrary(Py_ssize_t sipNrElem)
{
    return new ::RCCResourceLibrary[sipNrElem];
}


extern "C" {static void array_delete_RCCResourceLibrary(void *);}
static void array_delete_RCCResourceLibrary(void *sipCpp)
{
    delete[] reinterpret_cast< ::RCCResourceLibrary *>(sipCpp);
}


extern "C" {static void dealloc_RCCResourceLibrary(sipSimpleWrapper *);}
static void dealloc_RCCResourceLibrary(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_RCCResourceLibrary(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_RCCResourceLibrary(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_RCCResourceLibrary(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::RCCResourceLibrary *sipCpp = SIP_NULLPTR;

    {
        ::quint8 a0 = 3;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "|M", &a0))
        {
            sipCpp = new ::RCCResourceLibrary(a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_RCCResourceLibrary[] = {
    {sipName_compressionAlgorithm, meth_RCCResourceLibrary_compressionAlgorithm, METH_VARARGS, doc_RCCResourceLibrary_compressionAlgorithm},
    {sipName_dataFiles, meth_RCCResourceLibrary_dataFiles, METH_VARARGS, doc_RCCResourceLibrary_dataFiles},
    {sipName_failedResources, meth_RCCResourceLibrary_failedResources, METH_VARARGS, doc_RCCResourceLibrary_failedResources},
    {sipName_format, meth_RCCResourceLibrary_format, METH_VARARGS, doc_RCCResourceLibrary_format},
    {sipName_formatVersion, meth_RCCResourceLibrary_formatVersion, METH_VARARGS, doc_RCCResourceLibrary_formatVersion},
    {sipName_initName, meth_RCCResourceLibrary_initName, METH_VARARGS, doc_RCCResourceLibrary_initName},
    {sipName_noZstd, meth_RCCResourceLibrary_noZstd, METH_VARARGS, doc_RCCResourceLibrary_noZstd},
    {sipName_output, meth_RCCResourceLibrary_output, METH_VARARGS, doc_RCCResourceLibrary_output},
    {sipName_outputName, meth_RCCResourceLibrary_outputName, METH_VARARGS, doc_RCCResourceLibrary_outputName},
    {sipName_readFiles, meth_RCCResourceLibrary_readFiles, METH_VARARGS, doc_RCCResourceLibrary_readFiles},
    {sipName_resourceRoot, meth_RCCResourceLibrary_resourceRoot, METH_VARARGS, doc_RCCResourceLibrary_resourceRoot},
    {sipName_setCompressionAlgorithm, meth_RCCResourceLibrary_setCompressionAlgorithm, METH_VARARGS, doc_RCCResourceLibrary_setCompressionAlgorithm},
    {sipName_setFormat, meth_RCCResourceLibrary_setFormat, METH_VARARGS, doc_RCCResourceLibrary_setFormat},
    {sipName_setInitName, meth_RCCResourceLibrary_setInitName, METH_VARARGS, doc_RCCResourceLibrary_setInitName},
    {sipName_setInputFiles, meth_RCCResourceLibrary_setInputFiles, METH_VARARGS, doc_RCCResourceLibrary_setInputFiles},
    {sipName_setNoZstd, meth_RCCResourceLibrary_setNoZstd, METH_VARARGS, doc_RCCResourceLibrary_setNoZstd},
    {sipName_setOutputName, meth_RCCResourceLibrary_setOutputName, METH_VARARGS, doc_RCCResourceLibrary_setOutputName},
    {sipName_setResourceRoot, meth_RCCResourceLibrary_setResourceRoot, METH_VARARGS, doc_RCCResourceLibrary_setResourceRoot},
    {sipName_setUseNameSpace, meth_RCCResourceLibrary_setUseNameSpace, METH_VARARGS, doc_RCCResourceLibrary_setUseNameSpace},
    {sipName_setVerbose, meth_RCCResourceLibrary_setVerbose, METH_VARARGS, doc_RCCResourceLibrary_setVerbose},
    {sipName_useNameSpace, meth_RCCResourceLibrary_useNameSpace, METH_VARARGS, doc_RCCResourceLibrary_useNameSpace},
    {sipName_verbose, meth_RCCResourceLibrary_verbose, METH_VARARGS, doc_RCCResourceLibrary_verbose}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_RCCResourceLibrary[] = {
    {sipName_Zlib, static_cast<int>(::RCCResourceLibrary::CompressionAlgorithm::Zlib)},
    {sipName_Zstd, static_cast<int>(::RCCResourceLibrary::CompressionAlgorithm::Zstd)},
    {sipName_Best, static_cast<int>(::RCCResourceLibrary::CompressionAlgorithm::Best)},
    {sipName_None_, static_cast<int>(::RCCResourceLibrary::CompressionAlgorithm::None)},
    {sipName_Binary, static_cast<int>(::RCCResourceLibrary::Binary)},
    {sipName_C_Code, static_cast<int>(::RCCResourceLibrary::C_Code)},
    {sipName_Pass1, static_cast<int>(::RCCResourceLibrary::Pass1)},
    {sipName_Pass2, static_cast<int>(::RCCResourceLibrary::Pass2)},
    {sipName_Python_Code, static_cast<int>(::RCCResourceLibrary::Python_Code)},
    {0, 0}
};

PyDoc_STRVAR(doc_RCCResourceLibrary, "\1RCCResourceLibrary(formatVersion: int = 3)");


sipClassTypeDef sipTypeDef_rcc_backend_RCCResourceLibrary = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_RCCResourceLibrary,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_RCCResourceLibrary,
        {0, 0, 1},
        22, methods_RCCResourceLibrary,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_RCCResourceLibrary, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_RCCResourceLibrary,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_RCCResourceLibrary,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_RCCResourceLibrary,
    SIP_NULLPTR,
    array_RCCResourceLibrary,
    SIP_NULLPTR,
    release_RCCResourceLibrary,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_RCCResourceLibrary,
    sizeof (::RCCResourceLibrary),
};
